from office365.runtime.client_value import ClientValue


class ItemReference(ClientValue):
    """The ItemReference resource provides information necessary to address a DriveItem via the API."""
